--- hide: - navigation - toc - footer --- Download the data here. Note: This data is updated twice a day. For up-to-date results, consider using [the CLI tool][cli-tool] instead. ---

{% for key, val in stats_as_csv[0].items() %} {% if is_int(val) %} {{ key }} {% else %} | {{ key }} {% endif %} {% endfor %}
--- | ---
{% for row in stats_as_csv %}
{% for val in row.values() %} {{ val if is_int(val) else markdown.markdown(val) }} {% endfor %}
{% endfor %}